GOOGLE_MODEL_NOT_FOUND = "Google model not found"

# Purchase process errors
APPSFLYER_ID_NOT_FOUND = "appsflyer_id not found in data"
ADJUST_ADVERTISER_NOT_FOUND = "Adjust advertiser_id not found"

ALL_ZEROS = "00000000-0000-0000-0000-000000000000"
