PURCHASE_CREATE = "Purchase create"
GOOGLE_ERROR_LEVEL = "Google"
APPLE_ERROR_LEVEL = "Apple"
FACEBOOK_LOGGING_ERROR_LEVEL = "Facebook"
ADJUST_ERROR_LEVEL = "Adjust"
APPS_FLYER_ERROR_LEVEL = "Apps Flyer"
