# Google verify
GOOGLE_AUTH_URL = "https://www.googleapis.com/auth/androidpublisher"

# Apple verify
APPLE_URL = "https://buy.itunes.apple.com/verifyReceipt"
APPLE_SANDBOX_URL = "https://sandbox.itunes.apple.com/verifyReceipt"
APPLE_HEADERS = {"Content-Type": "application/x-www-form-urlencoded"}
